import { getPlatformEnv } from "@/utils";
import { mgop } from "@aligov/jssdk-mgop";
import zlbConfig from "@/common/js/zlbConfig";
import { getQuery } from "@/utils";
import zlbApi from "@/api/zlbApi";
import {httpApi} from "@/common/js/baseUrl";
let requestNum = 0;
// 请求地址为一下数组项时，请求不带请求头
const ignoreHeader = ["https://restapi.amap.com/v3/geocode/geo"];
function beginLoading(noLoading) {
  if (noLoading) return;

  if (requestNum === 0) {
    uni.showLoading({
      title: "加载中",
    });
  }

  requestNum++;
}

function endLoading(noLoading) {
  if (noLoading) return;
  requestNum--;

  if (requestNum <= 0) {
    requestNum = 0;
    uni.hideLoading();
  }
}

function getAppId() {
  const platform = uni.getSystemInfoSync().uniPlatform;
  const env = getPlatformEnv();
  let appId = "";
  switch (platform) {
    case "mp-weixin":
      appId = "wx";
      break;
    case "mp-alipay":
      appId = "zfb";
      break;
    default:
      if (env.bIsAlipayMini) {
        appId = "zlb_zfb";
      } else if (env.bIsDtDreamApp) {
        appId = "zlb_app";
      } else if (env.bIsWxMini) {
        appId = "zlb_wx";
      } else {
        //web端测试
        appId = "zlb_app";
      }
      break;
  }

  return appId;
}

function fetch(url, type = "get", data = {}, dataType, noLoading = false) {
  beginLoading(noLoading);
  return new Promise((resolve, reject) => {
    (url && url.startsWith("mgop.alibaba") )? handleMgop(url, type, data, dataType, noLoading, resolve, reject) : handleFetch(url, type, data, dataType, noLoading, resolve, reject);
  });
}

function uploadImg(url, filePath, formData = {}, noLoading = false) {
  beginLoading(noLoading);
  return new Promise((resolve, reject) => {
    uni.uploadFile({
      url: url,
      filePath: filePath,
      fileType: "image",
      name: "file",
      formData,
      header: {
        "content-type": "multipart/form-data",
        src: "wechat", // 小程序免登陆
        appid: getAppId(),
      },
      // 设置请求的 header
      success: function (res) {
        console.log("uploadImg--res", res);
        if (res.statusCode === 200 || res.statusCode === "200") {
          let item = res.data ? JSON.parse(res.data) : {};
          if (item.code === 0 || item.code === "0") {
            resolve(item);
          } else {
            // eslint-disable-next-line prefer-promise-reject-errors
            reject();
            uni.showToast({
              title: "服务异常",
              icon: "none",
              duration: 2000,
            });
          }
        } else {
          uni.showToast({
            title: "服务异常",
            icon: "none",
            duration: 2000,
          });
        }

        endLoading(noLoading);
      },
      fail: function (res) {
        console.log("uploadImg--fail", res); // eslint-disable-next-line prefer-promise-reject-errors

        uni.showToast({
          title: "服务异常",
          icon: "none",
          duration: 2000,
        });
        reject();
        endLoading(noLoading);
      },
    });
  });
}

function download(url, type = "get", data = {}, noLoading = false) {
  beginLoading(noLoading);
  return new Promise((resolve, reject) => {
    uni.request({
      url: url,
      method: type,
      responseType: "arraybuffer",
      header: {
        "Content-Type": "application/x-www-form-urlencoded; charset=UTF-8",
        src: "wechat",
        appid: getAppId(),
      },
      data: data,
      timeout: 10000,
      success: function (res) {
        endLoading(noLoading);
        console.log("返回结果:", res);
        if (res.statusCode === 200) {
          resolve(res);
        } else {
          reject(); // 接口不正常 reject
          uni.showToast({ title: "服务异常", icon: "none" });
        }
      },
      fail: function (err) {
        endLoading(noLoading);
        uni.showToast({ title: "服务异常", icon: "none" });
        reject(err);
      },
    });
  });
}
// 通用版upload,支持files或filePath方式上传
function commonUpload(config = { noLoading: false }) {
  const noLoading = config.noLoading ? true : false;
  beginLoading(noLoading);
  return new Promise((resolve, reject) => {
    uni.uploadFile({
      ...config,
      header: {
        /*   "content-type": "multipart/form-data", */
        src: "wechat", // 小程序免登陆
        appid: getAppId(),
      },
      // 设置请求的 header
      success: function (res) {
        console.log("uploadImg--res", res);
        if (res.statusCode === 200 || res.statusCode === "200") {
          let item = res.data ? JSON.parse(res.data) : {};
          if (item.code === 0 || item.code === "0") {
            resolve(item);
          } else {
            // eslint-disable-next-line prefer-promise-reject-errors
            reject();
            uni.showToast({
              title: "服务异常",
              icon: "none",
              duration: 2000,
            });
          }
        } else {
          uni.showToast({
            title: "服务异常",
            icon: "none",
            duration: 2000,
          });
        }

        endLoading(noLoading);
      },
      fail: function (res) {
        console.log("uploadImg--fail", res); // eslint-disable-next-line prefer-promise-reject-errors

        uni.showToast({
          title: "服务异常",
          icon: "none",
          duration: 2000,
        });
        reject();
        endLoading(noLoading);
      },
    });
  });
}


function handleMgop(url, type, data, dataType, noLoading, resolve, reject) {
  let extraHeader = {};
  // || window.location.href.includes('lastTest')
  // if (
  //   uni.getEnvVersion() === "development"
  // ) {
  /*  当请求头 isTestUrl 为 "1" 时，使用联调环境 */
  extraHeader.isTestUrl = "1";
  // }
  mgop({
    api: url, // 必填
    // host: 'https://mapi.zjzwfw.gov.cn/',
    dataType: "JSON",
    type: type,
    data: data,
    appKey: zlbConfig.appKey, // 必填
    header: {
      "Content-Type":
          dataType === "form"
              ? "application/x-www-form-urlencoded"
              : "application/json",
      src: "wechat", // 小程序免登陆
      appid:
          url === zlbApi.getAllIntegrationAppList ? "zlb_app" : getAppId(), //请求applist特殊处理，因为支付宝端未配置
      ...extraHeader,
    },
    onSuccess: (res) => {
      endLoading(noLoading);
      console.log("-----返回结果:",url, res,'-----');
      const code = res.ret[0].split("::")[0];
      if (code === "1000") {
        if (
            res.data.code === 0 ||
            res.data.code === "0" ||
            res.data.status === 0 ||
            res.data.status === "1" //高德地图
        ) {
          resolve(res.data);
        } else {
          //特殊处理下，获取门牌数据的接口code是1 ,是业务错误
          if(res.api==="mgop.alibaba.digitalDoorplate.getHomePageOneDoorplateFullInfo"){
            resolve(res.data);
          }else{
            reject(res);
            if (res.data.message || res.data.msg) {
              uni.showToast({
                title: res.data.message || res.data.msg,
                icon: "none",
                duration: 2000,
              });
            }
          }

        }
      } else {
        reject(res); // 接口不正常 reject
        endLoading(noLoading);
        uni.showToast({
          title: "服务异常",
          icon: "none",
          duration: 2000,
        });
      }
    },
    onFail: (err) => {
      endLoading(noLoading);
      reject(err);
    },
  });
}


function handleFetch(url, type, data, dataType, noLoading, resolve, reject) {
  let header = {};
  if (ignoreHeader.indexOf(url) === -1) {
    header = {
      "Content-Type":
          dataType === "form"
              ? "application/x-www-form-urlencoded"
              : "application/json",
      src: "wechat", // 小程序免登陆
      appid: getAppId(),
      Token:'1'
    };
  } else {
    header = {
      "Content-Type":
          dataType === "form"
              ? "application/x-www-form-urlencoded"
              : "application/json",
      Token:'1'
    };
  }
  uni.request({
    url: httpApi + url,
    method: type,
    header,
    data: data,
    timeout: 60000,
    success: function (res) {
      endLoading(noLoading);
      if (res.statusCode === 200) {
        if (
            res.data.code === 0 ||
            res.data.code === "0" ||
            res.data.status === 0 ||
            res.data.status === "1" //高德地图
        ) {
          resolve(res.data);
        } else {
          reject();
          if (res.data.message || res.data.msg) {
            uni.showToast({
              title: res.data.message || res.data.msg,
              icon: "none",
              duration: 2000,
            });
          }
        }
      } else {
        reject(); // 接口不正常 reject

        uni.showToast({
          title: "服务异常",
          icon: "none",
          duration: 2000,
        });
      }
    },
    fail: function (err) {
      console.log("err", err);
      endLoading(noLoading);
      uni.showToast({
        title: "服务异常",
        icon: "none",
        duration: 2000,
      });
      reject(err);
    },
    complete: function () {},
  });
}
export { uploadImg, fetch, download, commonUpload };
