import Vue from "vue";
import {templateDetails} from "@/api/commitment";
import {fetch as myFetch} from "@/api/fetch";

const state = {
    templateJson: {
        components:[]
    }
}

const mutations = {
    setTemplateComponents(state, data) {
        Vue.set(state.templateJson,'components',data)
    },
    //    修改setTemplateJson对应的组件配置
    setComponentValue(state,{index,value}){
        Vue.set(state.templateJson.components[index],'value',value)
    },
    // 修改inputValue
    setComponentInputValue(state,{index,value}){
        Vue.set(state.templateJson.components[index],'inputValue',value)
    },

}

const actions = {
    async getTemplateList({commit}, uuid) {
        try {
            const res = await templateDetails({
                uuid,
            })
            if (res.data && res.data.templateBody) {
                const result = handleResponse(res.data)
                commit('setTemplateComponents', result)
            } else {
                commit('setTemplateComponents', [])
            }
        } catch (e) {
            console.log(e)
        }
    }
}

const handleResponse = (data)  =>{
    let result = JSON.parse(data.templateBody)
    console.log('res',result)

    //如果有指标组件,对指标组件进行数据补充
    result.forEach( async item => {
        if(item.base.moduleName === "Instructions") {
            //对所有包含fetchConfig的组件进行数据请求
            for(let i = 0; i < item.config.length; i++) {
                if(item.config[i].fetchConfig) {
                    let fetchConfig = item.config[i].fetchConfig
                    let res = await myFetch(fetchConfig.api, 'get', fetchConfig.params, 'json')
                    res = res.data
                    item.config[i].options = res[fetchConfig.resListKey].map( resItem => {
                        return {
                            value: resItem[fetchConfig.valueKey],
                            name: resItem[fetchConfig.nameKey],
                            ...resItem
                        }
                    })
                }
            }
        }
    })
    return result
}

export default {
    namespaced: true,
    state,
    mutations,
    actions,
}